function R = calculateR(x)
%  
%  calculateR  calculate the potential scale reduction R
%
% INPUT:
%
%  x  N x M matrix, N is half of the number of sample and M is the number  
%     of all parameters plus one (the log likelihood function value).
%
% OUTPUT:
%
%  R  vector, the potential scale reduction R for each parameter.
%

m = length(x);
n = length(x{1})/2;

R = zeros(1,m);
for i=1:1:m
    phi = x{i}((n+1):length(x{i}),:);
    B = n*var(mean(phi));
    W = mean(var(phi));
    R(i) = sqrt(((n-1)*W/n+B/n)/W);
end
