function [res] = pplr(e, se, control, experiment)
%  
%  pplr   Calculate pplr
%  
% INPUT:
%
%  e          n x c matrix, containing the expression levels , n is the number 
%             of probe-sets and c is the number of conditions.
%  se         n x c matrix, containing the standard deviation of expression
%             level, n is the number of probe-sets and c is the number of 
%             conditions.
%  control    Integer, indicating the column in the data matrix related to the  
%             control.
%  experiment Integer, indicating the column in the data matrix related to
%             the experiment.
%
% OUTPUT:
%
%  res  n x 4 matrix. The first column is the original index sorted by the 
%       pplr values. The second column is the pplr values
%   

e1 = e(:,experiment);
e2 = e(:,control);
se1 = se(:,experiment);
se2 = se(:,control);

res = zeros(size(e,1),4);

p = (1-erf(-(e1-e2)./sqrt(2*(se1.^2+se2.^2))))/2;
[res(:,2) res(:,1)] = sort(p,'descend');
res(:,3) = e1(res(:,1))-e2(res(:,1));
res(:,4) = sqrt(se1(res(:,1)).^2+se2(res(:,1)).^2);
