function [lambda logF sig] = updatescale(x0,d)
%  
%  updatescale   update scale of Gaussian proposal distribution and sample 
%               lambda
%  
% INPUT:
%
%  x0  Double, the value of -log(lambda).
%  d - Boolean, 0 - start point, 1 - simulations.
%
% OUTPUT:
%
%  lambda  Double, simulated lambda.
%  logF    Double, the log likelihood function value.
%  sig     Double, the new scale of Gaussian proposal distribution.
%

global expr stdev rep muj accp

neF = 1;
nvar = 1;
[iGfun,jGvar] = find(ones(neF,nvar));
xlow = -1e20*ones(nvar,1);
xhigh = 1e20*ones(nvar,1);

options = optimset('GradObj','on','Display','off');
[x fopt exitflag] = fminunc('mcmcfun',x0,options);
     
secdri = sum((exp(x)*stdev)./(exp(x)+stdev).^2)/2+0.001*exp(-x)-...
         sum(((expr-muj(rep)).^2.*(exp(x).*stdev-exp(2*x)))./(exp(x)+stdev).^3)/2;

% sig of jump distribution
sig = 2.4*sqrt(1/secdri);
% sampling log(lambda^(-1))
if d==0
    x_samp = normrnd(x,sig,1);
else
    x_samp = normrnd(x0,sig,1);
end
lambda = exp(-x_samp);
logF = -mcmcloglikeli(lambda);

if d>0
    r = exp(-mcmcloglikeli(lambda)+mcmcloglikeli(exp(-x0)));
    if unifrnd(0,1)>min(r,1)
        lambda = exp(-x0);
        logF = -mcmcloglikeli(lambda);
        return;
    end
    accp = accp+1;
end
